==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/pt-br.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pt-br.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $


// Tradutor: Marclio Cunha Marinho Maia, 29/03/2003 s 04:34 (Goinia-GO,Brasil)
// E-mail: marcilio@nextsolution.com.br Web: http://www.nextsolution.com.br
// Icq: 22493131


$text['title']          = 'Informao Sobre o Sistema';

$text['vitals']         = 'Informaes Vitais do Sistema';
$text['hostname']       = 'Nome do Servidor';
$text['ip']             = 'Nmero IP';
$text['kversion']       = 'Verso do Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Tempo Ativo do Sistema';
$text['users']          = 'Usuarios Ativos';
$text['loadavg']        = 'Carga do Sistema';

$text['hardware']       = 'Informaes sobre o Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['mhz']            = 'Velocidade em MHz';
$text['cache']          = 'Tamanho do Cache';
$text['bogomips']       = 'Velocidade em Bogomips';
$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';

$text['netusage']       = 'Uso da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebido';
$text['sent']           = 'Enviado';
$text['errors']         = 'Perdido';

$text['connections']    = 'Conexes Estabelecidas';

$text['memusage']       = 'Utilizao Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Memria Virtual (SWAP)';

$text['fs']             = 'Sistemas de Arquivos';
$text['mount']          = 'Ponto de montagem';
$text['partition']      = 'Partio';

$text['percent']        = 'Capacidade Utilizada';
$text['type']           = 'Tipo';
$text['free']           = 'Livre';
$text['used']           = 'Utilizado';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'N/A';

$text['capacity']       = 'Capacidade'; 

$text['template']       = 'Exemplos';
$text['language']       = 'Lngua';
$text['submit']         = 'Entrar';
$text['created']        = 'Criado por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'Dias';
$text['hours']          = 'Horas';
$text['minutes']        = 'Minutos';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/pt-br.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pt-br.php,v 1.6 2004/08/30 15:51:26 webbie Exp $
//
// Tradutor: Marclio Cunha Marinho Maia, 29/03/2003 s 04:34 (Goinia-GO,Brasil)
// E-mail: marcilio@nextsolution.com.br Web: http://www.nextsolution.com.br
// Icq: 22493131

$text['title']          = 'Informao Sobre o Sistema';

$text['vitals']         = 'Informaes Vitais do Sistema';
$text['hostname']       = 'Nome do Servidor';
$text['ip']             = 'Nmero IP';
$text['kversion']       = 'Verso do Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Tempo Ativo do Sistema';
$text['users']          = 'Usuarios Ativos';
$text['loadavg']        = 'Carga do Sistema';

$text['hardware']       = 'Informaes sobre o Hardware';
$text['numcpu']         = 'Processadores';
$text['cpumodel']       = 'Modelo';
$text['cpuspeed']       = 'Velocidade em MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tamanho do Cache';
$text['bogomips']       = 'Velocidade em Bogomips';

$text['pci']            = 'Dispositivos PCI';
$text['ide']            = 'Dispositivos IDE';
$text['scsi']           = 'Dispositivos SCSI';
$text['usb']            = 'Dispositivos USB';

$text['netusage']       = 'Uso da Rede';
$text['device']         = 'Dispositivo';
$text['received']       = 'Recebido';
$text['sent']           = 'Enviado';
$text['errors']         = 'Perdido';

$text['connections']    = 'Conexes Estabelecidas';

$text['memusage']       = 'Utilizao Memria';
$text['phymem']         = 'Memria Fsica';
$text['swap']           = 'Memria Virtual (SWAP)';

$text['fs']             = 'Sistemas de Arquivos';
$text['mount']          = 'Ponto de montagem';
$text['partition']      = 'Partio';

$text['percent']        = 'Capacidade Utilizada';
$text['type']           = 'Tipo';
$text['free']           = 'Livre';
$text['used']           = 'Utilizado';
$text['size']           = 'Tamanho';
$text['totals']         = 'Totais';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'N/A';

$text['capacity']       = 'Capacidade'; 

$text['template']       = 'Exemplos';
$text['language']       = 'Lngua';
$text['submit']         = 'Entrar';
$text['created']        = 'Criado por';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'Dias';
$text['hours']          = 'Horas';
$text['minutes']        = 'Minutos';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
